######################################################################
# Create a web server using AdminTask.createWebServerByHostName.
# Also adds HostAliases for the webPort and webSSLPort to default_host
# Usage:
#    CreateWebServer.py <options>
#
# Options:
#    Required:
#       *webserverName     - Specify the name for this Web server defintion.
#       *hostName          - Specify the host name where the Web server is installed.
#       *platform          - platformDesc
#       *pluginInstallRoot - Plugin Install Root.
#
#    Optional:
#       templateName       - TemplateNameDesc
#       webPort            - Web server Port.
#       webSSLPort         - Web server SSL Port.
#       webInstallRoot     - Install Root for Web server.
#       configurationFile  - Path to the configuration file for the web server
#       serviceName        - Windows ServiceName for starting IHS Web server as a Service.
#       webProtocol        - Web server protocol.
#       webAppMapping      - Web server application mapping.
#       adminPort          - IBM Administration Server Port.
#       adminUserID        - IBM Administration Server userID.
#       adminPasswd        - IBM Administration Server userID password.
#       adminProtocol      - IBM Administration Server protocol.
#       errorLogfile
#       accessLogfile
#



import sys
import traceback
from java.lang import System
from java.io import File



try:
	NL = System.getProperty('line.separator')
	
	# Get our cell, node, and server names
	PROFILE = System.getProperty('user.install.root')
	CELL    = AdminControl.getCell()
	NODE    = AdminControl.getNode()
	DEFAULT_HOST = AdminConfig.getid("/VirtualHost:default_host")
	
	
	
	# Get the server name argument
	SERVER  = None
	try:
		SERVER = sys.argv[sys.argv.index('-webserverName') + 1]
	except:
		print '-webserverName is required'
		sys.exit(1)
	#endtry
	
	
	
	# Get our HTTP and SSL ports, if specified
	webPort = None
	try:
		webPort = sys.argv[sys.argv.index('-webPort') + 1]
	except:
		pass
	#endtry
	
	webSSLPort = None
	try:
		# Get the index of the ssl port arg
		webSSLPortIndex = sys.argv.index('-webSSLPort')
		
		# Remove the SSL argument and save it in a variable, since it's not part of the official AdminTask API
		sys.argv.pop(webSSLPortIndex)
		webSSLPort = sys.argv.pop(webSSLPortIndex)
	except:
		pass
	#endtry
	
	
	
	# Create the new web server
	AdminTask.createWebServerByHostName(sys.argv)
	
	
	
	# Add HostAliases for the web port and ssl port, if necessary
	# Get existing ports
	existingPorts = {}
	for hostAlias in AdminConfig.list("HostAlias", DEFAULT_HOST).split(NL):
		hostname = AdminConfig.showAttribute(hostAlias, "hostname")
		port     = AdminConfig.showAttribute(hostAlias, "port")
		if hostname == "*" and port != "":
			existingPorts[port] = 1
		#endif
	#endfor
	
	if (webPort is not None) and (webPort not in existingPorts.keys()):
		AdminConfig.create("HostAlias", DEFAULT_HOST, [["hostname","*"], ["port",webPort]])	
		existingPorts[webPort] = 1
	#endif
	
	if (webSSLPort is not None) and (webSSLPort not in existingPorts.keys()):
		AdminConfig.create("HostAlias", DEFAULT_HOST, [["hostname","*"], ["port",webSSLPort]])
		existingPorts[webSSLPort] = 1
	#endif
	
	
	
	# Save, which will write out our new keystore
	AdminConfig.save()
	
	
	
	# Get the key store file
	configDir = File(PROFILE, "config")
	keyStoreFile = File(configDir, "cells/%s/nodes/%s/servers/%s/plugin-key.kdb" % (CELL, NODE, SERVER))
	
	
	
	# If a keystore was created for us, propagate it to the plugins config directory
	if keyStoreFile.isFile():
		# Get the plugin-cfg.xml generator MBean
		generator = AdminControl.completeObjectName('type=PluginCfgGenerator,cell=%s,node=%s,*' % (CELL, NODE))
		
		# Generate, propagate, and copy key files
		AdminControl.invoke(generator, 'propagateKeyring', '"%s" "%s" "%s" "%s"' % (configDir.getAbsolutePath(), CELL, NODE, SERVER))
	#endif
except:
	traceback.print_exc();
	sys.exit(1)
#endtry



sys.exit(0)
